@@ -105,35 +105,20 @@ IncidenceRecurrence::IncidenceRecurrence(IncidenceDateTime *dateTime, Ui::EventO
             &IncidenceRecurrence::handleExceptionDateChange);
     connect(mUi->mExceptionList, &QListWidget::itemSelectionChanged, this,
             &IncidenceRecurrence::updateRemoveExceptionButton);
-    connect(mUi->mRecurrenceTypeCombo,
-            static_cast<void (KComboBox::*)(int)>(&KComboBox::currentIndexChanged), this,
-            &IncidenceRecurrence::handleRecurrenceTypeChange);
-    connect(mUi->mEndDurationEdit, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged),
-            this, &IncidenceRecurrence::handleEndAfterOccurrencesChange);
-    connect(mUi->mFrequencyEdit, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged),
-            this, &IncidenceRecurrence::handleFrequencyChange);
+    connect(mUi->mRecurrenceTypeCombo, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &IncidenceRecurrence::handleRecurrenceTypeChange);
+    connect(mUi->mEndDurationEdit, QOverload<int>::of(&QSpinBox::valueChanged), this, &IncidenceRecurrence::handleEndAfterOccurrencesChange);
+    connect(mUi->mFrequencyEdit, QOverload<int>::of(&QSpinBox::valueChanged), this, &IncidenceRecurrence::handleFrequencyChange);
 
     // Check the dirty status when the user changes values.
-    connect(mUi->mRecurrenceTypeCombo,
-            static_cast<void (KComboBox::*)(int)>(&KComboBox::currentIndexChanged), this,
-            &IncidenceRecurrence::checkDirtyStatus);
-    connect(mUi->mFrequencyEdit, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged),
-            this, &IncidenceRecurrence::checkDirtyStatus);
-    connect(mUi->mFrequencyEdit, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged),
-            this, &IncidenceRecurrence::checkDirtyStatus);
+    connect(mUi->mRecurrenceTypeCombo, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &IncidenceRecurrence::checkDirtyStatus);
+    connect(mUi->mFrequencyEdit, QOverload<int>::of(&QSpinBox::valueChanged), this, &IncidenceRecurrence::checkDirtyStatus);
+    connect(mUi->mFrequencyEdit, QOverload<int>::of(&QSpinBox::valueChanged), this, &IncidenceRecurrence::checkDirtyStatus);
     connect(mUi->mWeekDayCombo, &KPIM::KWeekdayCheckCombo::checkedItemsChanged, this,
             &IncidenceRecurrence::checkDirtyStatus);
-    connect(mUi->mMonthlyCombo,
-            static_cast<void (KComboBox::*)(int)>(&KComboBox::currentIndexChanged), this,
-            &IncidenceRecurrence::checkDirtyStatus);
-    connect(mUi->mYearlyCombo,
-            static_cast<void (KComboBox::*)(int)>(&KComboBox::currentIndexChanged), this,
-            &IncidenceRecurrence::checkDirtyStatus);
-    connect(mUi->mRecurrenceEndCombo,
-            static_cast<void (KComboBox::*)(int)>(&KComboBox::currentIndexChanged), this,
-            &IncidenceRecurrence::checkDirtyStatus);
-    connect(mUi->mEndDurationEdit, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged),
-            this, &IncidenceRecurrence::checkDirtyStatus);
+    connect(mUi->mMonthlyCombo, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &IncidenceRecurrence::checkDirtyStatus);
+    connect(mUi->mYearlyCombo, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &IncidenceRecurrence::checkDirtyStatus);
+    connect(mUi->mRecurrenceEndCombo, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &IncidenceRecurrence::checkDirtyStatus);
+    connect(mUi->mEndDurationEdit, QOverload<int>::of(&QSpinBox::valueChanged), this, &IncidenceRecurrence::checkDirtyStatus);
     connect(mUi->mRecurrenceEndDate, &KDateComboBox::dateChanged, this,
             &IncidenceRecurrence::checkDirtyStatus);
     connect(mUi->mThisAndFutureCheck, &QCheckBox::stateChanged, this,
@@ -445,11 +430,11 @@ bool IncidenceRecurrence::isValid() const
     // Check if the incidence will occur at least once
     if (incidence->recurs()) {
         // dtStart for events, dtDue for to-dos
-        const KDateTime referenceDate
+        const QDateTime referenceDate
             = incidence->dateTime(KCalCore::Incidence::RoleRecurrenceStart);
 
         if (referenceDate.isValid()) {
-            if (!(incidence->recurrence()->recursOn(referenceDate.date(), referenceDate.timeSpec())
+            if (!(incidence->recurrence()->recursOn(referenceDate.date(), referenceDate.timeZone())
                   || incidence->recurrence()->getNextDateTime(referenceDate).isValid())) {
                 mLastErrorString = i18n("A recurring event or to-do must occur at least once. "
                                         "Adjust the recurring parameters.");
@@ -629,10 +614,10 @@ void IncidenceRecurrence::handleRecurrenceTypeChange(int currentIndex)
     }
 
     const QString labelEvery = ki18ncp("repeat >every< N years/months/...; "
-                         "dynamic context 'type': 'd' days, 'w' weeks, "
-                         "'m' months, 'y' years",
-                         "every", "every").
-                 subs(frequency).inContext(QStringLiteral("type"), freqKey).toString();
+                                       "dynamic context 'type': 'd' days, 'w' weeks, "
+                                       "'m' months, 'y' years",
+                                       "every", "every").
+                               subs(frequency).inContext(QStringLiteral("type"), freqKey).toString();
     mUi->mFrequencyLabel->setText(labelEvery);
     mUi->mRecurrenceRuleLabel->setText(labelFreq);
 
@@ -654,7 +639,7 @@ void IncidenceRecurrence::removeExceptions()
 
 void IncidenceRecurrence::updateRemoveExceptionButton()
 {
-    mUi->mExceptionRemoveButton->setEnabled(mUi->mExceptionList->selectedItems().count() > 0);
+    mUi->mExceptionRemoveButton->setEnabled(!mUi->mExceptionList->selectedItems().isEmpty());
 }
 
 void IncidenceRecurrence::updateWeekDays(const QDate &newStartDate)
@@ -775,7 +760,7 @@ void IncidenceRecurrence::selectMonthlyItem(KCalCore::Recurrence *recurrence, us
 
         if (rmp.first().pos() > 0) {   // nth day
             // TODO if ( rmp.first().pos() != mDateTime->startDate().day() ) { warn user }
-            // NOTE: This silencly changes the recurrence when:
+            // NOTE: This silently changes the recurrence when:
             //       rmp.first().pos() != mDateTime->startDate().day()
             mUi->mMonthlyCombo->setCurrentIndex(ComboIndexMonthlyPos);
         } else { // (month.last() - n)th day
@@ -949,7 +934,7 @@ void IncidenceRecurrence::toggleRecurrenceWidgets(int recurrenceType)
     mUi->mExceptionAddButton->setVisible(enable);
     mUi->mExceptionAddButton->setEnabled(mUi->mExceptionDateEdit->date() >= currentDate());
     mUi->mExceptionRemoveButton->setVisible(enable);
-    mUi->mExceptionRemoveButton->setEnabled(mUi->mExceptionList->selectedItems().count() > 0);
+    mUi->mExceptionRemoveButton->setEnabled(!mUi->mExceptionList->selectedItems().isEmpty());
     mUi->mExceptionList->setVisible(enable);
     mUi->mThisAndFutureCheck->setVisible(recurrenceType == RecurrenceTypeException);
 }
