@@ -54,10 +54,10 @@ public:
 
     void load(const KCalCore::Incidence::Ptr &incidence) override;
     void save(const KCalCore::Incidence::Ptr &incidence) override;
-    bool isDirty() const override;
-    bool isValid() const override;
+    Q_REQUIRED_RESULT bool isDirty() const override;
+    Q_REQUIRED_RESULT bool isValid() const override;
 
-    RecurrenceType currentRecurrenceType() const;
+    Q_REQUIRED_RESULT RecurrenceType currentRecurrenceType() const;
 
 Q_SIGNALS:
     void recurrenceChanged(IncidenceEditorNG::RecurrenceType type);
@@ -117,15 +117,15 @@ private:
     QDate currentDate() const;
 
 private:
-    Ui::EventOrTodoDesktop *mUi;
+    Ui::EventOrTodoDesktop *mUi = nullptr;
     QDate mCurrentDate;
-    IncidenceDateTime *mDateTime;
+    IncidenceDateTime *mDateTime = nullptr;
     KCalCore::DateList mExceptionDates;
 
     // So we can easily detect if the user changed the type,
     // without going through complicated recurrence logic:
-    int mMonthlyInitialType;
-    int mYearlyInitialType;
+    int mMonthlyInitialType = -1;
+    int mYearlyInitialType = -1;
 };
 }
 
