@@ -33,10 +33,7 @@
 
 using namespace IncidenceEditorNG;
 
-IndividualMailDialog::IndividualMailDialog(const QString &question,
-                                           const KCalCore::Attendee::List &attendees,
-                                           const KGuiItem &buttonYes, const KGuiItem &buttonNo,
-                                           QWidget *parent)
+IndividualMailDialog::IndividualMailDialog(const QString &question, const KCalCore::Attendee::List &attendees, const KGuiItem &buttonYes, const KGuiItem &buttonNo, QWidget *parent)
     : QDialog(parent)
 {
     setWindowTitle(i18nc("@title:window", "Group Scheduling Email"));
@@ -51,6 +48,10 @@ IndividualMailDialog::IndividualMailDialog(const QString &question,
                                "Send no update"), QVariant(NoUpdate));
         options->addItem(i18nc("@item:inlistbox ITIP Messages for one attendee",
                                "Edit mail"), QVariant(Edit));
+        options->setWhatsThis(i18nc("@info:whatsthis",
+                                    "Options for this particular attendee."));
+        options->setToolTip(i18nc("@info:tooltip",
+                                  "Choose an option for this attendee."));
         mAttendeeDecision[attendee] = options;
 
         layout->addWidget(new QLabel(attendee->fullName()), row, 0);
@@ -68,7 +69,7 @@ IndividualMailDialog::IndividualMailDialog(const QString &question,
     topLayout->addWidget(mW);
     topLayout->addWidget(m_detailsWidget);
 
-    m_buttons = new QDialogButtonBox;
+    m_buttons = new QDialogButtonBox(this);
     m_buttons->setStandardButtons(
         QDialogButtonBox::Yes | QDialogButtonBox::No | QDialogButtonBox::Help);
     auto yesButton = m_buttons->button(QDialogButtonBox::Yes);
@@ -82,7 +83,7 @@ IndividualMailDialog::IndividualMailDialog(const QString &question,
         done(QDialogButtonBox::No);
     });
     auto detailsButton = m_buttons->button(QDialogButtonBox::Help);
-    detailsButton->setIcon(QIcon::fromTheme(QLatin1String("help-about")));
+    detailsButton->setIcon(QIcon::fromTheme(QStringLiteral("help-about")));
     connect(detailsButton, &QPushButton::clicked, this, [this]() {
         m_detailsWidget->setVisible(!m_detailsWidget->isVisible());
         updateButtonState();
@@ -92,7 +93,6 @@ IndividualMailDialog::IndividualMailDialog(const QString &question,
     updateButtonState();
 
     topLayout->addWidget(m_buttons);
-    setLayout(topLayout);
 }
 
 IndividualMailDialog::~IndividualMailDialog()
